@@ -48,6 +48,7 @@
 #include <QtGui/QFont>
 #include <QtGui/QAction>
 #include <QtGui/QComboBox>
+#include <QtGui/QScrollArea>
 #include <QtGui/QStackedWidget>
 
 static const char SETTINGSKEYSECTIONNAME[] = "SearchResults";
@@ -57,7 +58,28 @@ namespace Find {
 
 namespace Internal {
 
-    class SearchResultWindowPrivate : public QObject {
+    class InternalScrollArea : public QScrollArea
+    {
+        Q_OBJECT
+    public:
+        explicit InternalScrollArea(QWidget *parent)
+            : QScrollArea(parent)
+        {
+            setFrameStyle(QFrame::NoFrame);
+            setVerticalScrollBarPolicy(Qt::ScrollBarAsNeeded);
+            setHorizontalScrollBarPolicy(Qt::ScrollBarAsNeeded);
+        }
+
+        QSize sizeHint() const
+        {
+            if (widget())
+                return widget()->size();
+            return QScrollArea::sizeHint();
+        }
+    };
+
+    class SearchResultWindowPrivate : public QObject
+    {
         Q_OBJECT
     public:
         SearchResultWindowPrivate(SearchResultWindow *window);
@@ -209,7 +231,10 @@ SearchResultWindow::SearchResultWindow(QWidget *newSearchPanel)
     d->m_widget = new QStackedWidget;
     d->m_widget->setWindowTitle(displayName());
 
-    d->m_widget->addWidget(newSearchPanel);
+    InternalScrollArea *newSearchArea = new InternalScrollArea(d->m_widget);
+    newSearchArea->setWidget(newSearchPanel);
+    newSearchArea->setFocusProxy(newSearchPanel);
+    d->m_widget->addWidget(newSearchArea);
     d->m_currentIndex = 0;
 
     d->m_expandCollapseButton = new QToolButton(d->m_widget);
@@ -400,7 +425,7 @@ void SearchResultWindow::setTextEditorFont(const QFont &font)
 void SearchResultWindow::openNewSearchPanel()
 {
     d->setCurrentIndex(0);
-    popup();
+    popup(true/*focus*/, true/*sizeHint*/);
 }
 
 /*!
